<?php
namespace Drupal\off_canvas_menu\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Cache\CacheTagsInvalidatorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class OffCanvasMenuSettingsForm extends ConfigFormBase {
    protected $cacheTagInvalidator;

    public function __construct(CacheTagsInvalidatorInterface $cacheTagInvalidator) {
        $this->cacheTagInvalidator = $cacheTagInvalidator;
    }

    public static function create(ContainerInterface $container) {
        return new static(
            $container->get('cache_tags.invalidator')
        );
    }

    public function getFormId() {
        return 'off_canvas_menu_settings_form';
    }

    protected function getEditableConfigNames() {
        return ['off_canvas_menu.settings'];
    }

    public function buildForm(array $form, FormStateInterface $form_state) {
        $config = $this->config('off_canvas_menu.settings');

        $menu_storage = \Drupal::entityTypeManager()->getStorage('menu');
        $menus = $menu_storage->loadMultiple();

        $menu_options = [];
        foreach ($menus as $menu) {
            $menu_options[$menu->id()] = $menu->label();
        }

        $form['menu_name'] = [
            '#type' => 'select',
            '#title' => $this->t('Select Menu to Use'),
            '#options' => $menu_options,
            '#default_value' => $config->get('menu_name'),
        ];

        $form['icon_position'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Hamburger Icon CSS Position'),
            '#default_value' => $config->get('icon_position'),
            '#description' => $this->t('CSS style string, e.g. top: 20px; left: 20px;'),
        ];

        $form['icon_position_mode'] = [
            '#type' => 'select',
            '#title' => $this->t('CSS Hamburger Icon Position Type'),
            '#options' => [
                'absolute' => $this->t('Absolute'),
                'fixed' => $this->t('Fixed'),
            ],
            '#default_value' => $config->get('icon_position_mode') ?: 'absolute',
            '#description' => $this->t('Choose whether the toggle icon is absolute or fixed positioned on the screen.'),
        ];

        $form['menu_location'] = [
            '#type' => 'select',
            '#title' => $this->t('Menu Location on Screen'),
            '#options' => [
                'left' => $this->t('Left'),
                'right' => $this->t('Right'),
                'top' => $this->t('Top'),
                'bottom' => $this->t('Bottom'),
            ],
            '#default_value' => $config->get('menu_location') ?: 'left',
            '#description' => $this->t('This determines where the menu is positioned on the screen.'),
        ];

        $form['slide_direction'] = [
            '#type' => 'select',
            '#title' => $this->t('Slide In From Direction'),
            '#options' => [
                'left' => $this->t('Left'),
                'right' => $this->t('Right'),
                'top' => $this->t('Top'),
                'bottom' => $this->t('Bottom'),
            ],
            '#default_value' => $config->get('slide_direction') ?: 'left',
            '#description' => $this->t('This determines the direction from which the menu slides into view.'),
        ];

        $form['transition_duration'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Transition Duration'),
            '#default_value' => $config->get('transition_duration') ?: '0.3s',
            '#description' => $this->t('Enter a valid CSS duration (e.g. "0.3s", "500ms").'),
        ];

        $form['transition_ease'] = [
            '#type' => 'select',
            '#title' => $this->t('Transition Timing Function'),
            '#options' => [
                'ease' => $this->t('Ease'),
                'linear' => $this->t('Linear'),
                'ease-in' => $this->t('Ease-in'),
                'ease-out' => $this->t('Ease-out'),
                'ease-in-out' => $this->t('Ease-in-out'),
            ],
            '#default_value' => $config->get('transition_ease') ?: 'ease',
            '#description' => $this->t('Choose the easing style for the menu slide-in.'),
        ];

        return parent::buildForm($form, $form_state);
    }

    public function submitForm(array &$form, FormStateInterface $form_state) {
        parent::submitForm($form, $form_state);

        $this->config('off_canvas_menu.settings')
            ->set('menu_name', $form_state->getValue('menu_name'))
            ->set('icon_position', $form_state->getValue('icon_position'))
            ->set('icon_position_mode', $form_state->getValue('icon_position_mode'))
            ->set('menu_location', $form_state->getValue('menu_location'))
            ->set('slide_direction', $form_state->getValue('slide_direction'))
            ->set('transition_duration', $form_state->getValue('transition_duration'))
            ->set('transition_ease', $form_state->getValue('transition_ease'))
            ->save();

        $this->cacheTagInvalidator->invalidateTags(['off_canvas_menu_block']);
    }
}
