<?php

namespace Drupal\off_canvas_menu\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\off_canvas_menu\Menu\MenuService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an Off Canvas Menu block.
 *
 * @Block(
 *   id = "off_canvas_menu_block",
 *   admin_label = @Translation("Off Canvas Menu")
 * )
 */
class OffCanvasMenuBlock extends BlockBase implements ContainerFactoryPluginInterface {

    protected $menuService;
    protected $configFactory;

    public function __construct(array $configuration, $plugin_id, $plugin_definition, MenuService $menuService, ConfigFactoryInterface $configFactory) {
        parent::__construct($configuration, $plugin_id, $plugin_definition);
        $this->menuService = $menuService;
        $this->configFactory = $configFactory;
    }

    public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
        return new static(
            $configuration,
            $plugin_id,
            $plugin_definition,
            $container->get('off_canvas_menu.menu_service'),
            $container->get('config.factory')
        );
    }

    public function build() {
        $config = $this->configFactory->get('off_canvas_menu.settings');
        $menu_name = $config->get('menu_name') ?: 'main';
        $position = $config->get('icon_position') ?: 'top: 10px; left: 10px;';
        $position_mode = $config->get('icon_position_mode') ?: 'absolute';
        $menu_location = $config->get('menu_location') ?: 'left';
        $slide_direction = $config->get('slide_direction') ?: 'left';
        $transition_duration = $config->get('transition_duration') ?: '0.3s';
        $transition_ease = $config->get('transition_ease') ?: 'ease';

        return [
            '#theme' => 'off_canvas_menu',
            '#menu' => $this->menuService->buildMenu($menu_name),
            '#position' => $position,
            '#position_mode' => $position_mode,
            '#menu_location' => $menu_location,
            '#slide_direction' => $slide_direction,
            '#transition_duration' => $transition_duration,
            '#transition_ease' => $transition_ease,
            '#attached' => [
                'library' => ['off_canvas_menu/off_canvas_menu'],
            ],
            '#cache' => [
                'tags' => ['off_canvas_menu_block'],
            ],
        ];
    }
}
